@@ -41,9 +41,14 @@ namespace TiCC {
     bool fill( const std::string& );
     bool fill( const std::string&, const std::string& );
     bool hasSection( const std::string& ) const;
-    std::string lookUp( const std::string&, const std::string& = "" ) const;
+    std::string lookUp( const std::string& v,
+			const std::string& s = "" ) const {
+      return getatt( v, s );
+    }
     ssMap lookUpAll( const std::string& ) const;
     std::set<std::string> lookUpSections() const;
+    std::string getatt( const std::string&,
+			const std::string& = "" ) const;
     std::string setatt( const std::string&,
 			const std::string&,
 			const std::string& = "" );
