@@ -1,10 +1,7 @@
 /*
-  $Id: LogBuffer.h 16817 2014-01-06 10:07:03Z sloot $
-  $URL: https://ilk.uvt.nl/svn/sources/libticcutils/trunk/include/ticcutils/LogBuffer.h $
-
-  Copyright (c) 1998 - 2014
+  Copyright (c) 2006 - 2016
+  CLST  - Radboud University
   ILK   - Tilburg University
-  CLiPS - University of Antwerp
 
   This file is part of ticcutils
 
@@ -22,10 +19,11 @@
   along with this program; if not, see <http://www.gnu.org/licenses/>.
 
   For questions and suggestions, see:
-      http://ilk.uvt.nl/software.html
+      https://github.com/LanguageMachines/ticcutils/issues
   or send mail to:
-      timbl@uvt.nl
+      lamasoftware (at ) science.ru.nl
 */
+
 #ifndef TICC_LOGBUFFER_H
 #define TICC_LOGBUFFER_H
 
@@ -44,8 +42,16 @@ enum LogFlag { NoStamp=0, StampTime=1, StampMessage=2, StampBoth=3 };
 template <class charT, class traits = std::char_traits<charT> >
   class basic_log_buffer : public std::basic_streambuf<charT, traits> {
  public:
- basic_log_buffer( std::basic_ostream<charT,traits>&, const std::string& = "",
-		   const LogFlag = StampBoth );
+ basic_log_buffer( std::basic_ostream<charT,traits>& a,
+		   const std::string& mess = "",
+		   const LogFlag flag = StampBoth ):
+ ass_stream( &a ),
+ stamp_flag( flag ),
+ in_sync(true),
+ level(LogNormal),
+ threshold_level(LogNormal),
+ ass_mess( mess )
+ {};
   ~basic_log_buffer();
   //
   // setters/getters
@@ -78,17 +84,6 @@ template <class charT, class traits = std::char_traits<charT> >
 typedef basic_log_buffer<char, std::char_traits<char> > LogBuffer;
 typedef basic_log_buffer<wchar_t, std::char_traits<wchar_t> > wLogBuffer;
 
-template <class charT, class traits >
-basic_log_buffer<charT,traits>::basic_log_buffer( std::basic_ostream<charT,traits>& a,
-						  const std::string& mess,
-						  const LogFlag stamp ) {
-  ass_stream = &a;
-  ass_mess = mess;
-  stamp_flag = stamp;
-  in_sync = true;
-  level = LogNormal;
-  threshold_level = LogSilent;
-}
 
 template <class charT, class traits >
 basic_log_buffer<charT,traits>::~basic_log_buffer(){
@@ -122,7 +117,9 @@ inline std::string time_stamp(){
 template <class charT, class traits >
 int basic_log_buffer<charT,traits>::overflow( int c ) {
   buffer_out();
-  if ( level > threshold_level && c != '\r' ){
+  if ( level >= threshold_level && c != '\r' ){
+    //    std::cerr << "overflow OK: " << level << " >= " << threshold_level
+    //	      << "(" << char(c) << ")" << std::endl;
     if ( c != EOF ){
       char z = static_cast<char>(c);
       ass_stream->put( z );
@@ -142,7 +139,8 @@ int basic_log_buffer<charT,traits>::sync() {
 
 template <class charT, class traits >
 void basic_log_buffer<charT,traits>::buffer_out(){
-  if ( level > threshold_level ){
+  if ( level >= threshold_level ){
+    //    std::cerr << "buffer_out OK: " << level << " >= " << threshold_level << std::endl;
     // only output when we are on a high enough level
     if ( in_sync ) {
       // stamps and messages are only displayed when in sync
