@@ -1,10 +1,7 @@
 /*
-  $Id: LogStream.h 17621 2014-09-08 10:24:50Z mvgompel $
-  $URL: https://ilk.uvt.nl/svn/sources/libticcutils/trunk/include/ticcutils/LogStream.h $
-
-  Copyright (c) 1998 - 2014
+  Copyright (c) 2006 - 2016
+  CLST  - Radboud University
   ILK   - Tilburg University
-  CLiPS - University of Antwerp
 
   This file is part of ticcutils
 
@@ -22,9 +19,9 @@
   along with this program; if not, see <http://www.gnu.org/licenses/>.
 
   For questions and suggestions, see:
-      http://ilk.uvt.nl/software.html
+      https://github.com/LanguageMachines/ticcutils/issues
   or send mail to:
-      timbl@uvt.nl
+      lamasoftware (at ) science.ru.nl
 */
 #ifndef TICC_LOGSTREAM_H
 #define TICC_LOGSTREAM_H
@@ -110,7 +107,7 @@ namespace TiCC {
 
   class Log{
   public:
-    Log( LogStream *l );
+    Log( LogStream * );
     Log( LogStream& l );
     ~Log();
     LogStream& operator *();
@@ -124,7 +121,7 @@ namespace TiCC {
   class Dbg{
   public:
     Dbg( LogStream * );
-    Dbg( LogStream&  );
+    Dbg( LogStream& l );
     ~Dbg();
     LogStream& operator *();
   private:
@@ -137,7 +134,7 @@ namespace TiCC {
   class xDbg{
   public:
     xDbg( LogStream * );
-    xDbg( LogStream&  );
+    xDbg( LogStream& l );
     ~xDbg();
     LogStream& operator *();
   private:
@@ -150,7 +147,7 @@ namespace TiCC {
   class xxDbg{
   public:
     xxDbg( LogStream * );
-    xxDbg( LogStream&  );
+    xxDbg( LogStream& l );
     ~xxDbg();
     LogStream& operator *();
   private:
