@@ -1,19 +1,16 @@
 /*
-  $Id: XMLtools.h 16817 2014-01-06 10:07:03Z sloot $
-  $URL: https://ilk.uvt.nl/svn/sources/libticcutils/trunk/include/ticcutils/XMLtools.h $
-
-  Copyright (c) 1998 - 2014
+  Copyright (c) 2006 - 2016
+  CLST  - Radboud University
   ILK   - Tilburg University
-  CLiPS - University of Antwerp
 
   This file is part of ticcutils
 
-  timbl is free software; you can redistribute it and/or modify
+  ticcutils is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
   (at your option) any later version.
 
-  timbl is distributed in the hope that it will be useful,
+  ticcutils is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
@@ -22,9 +19,9 @@
   along with this program; if not, see <http://www.gnu.org/licenses/>.
 
   For questions and suggestions, see:
-      http://ilk.uvt.nl/software.html
+      https://github.com/LanguageMachines/ticcutils/issues
   or send mail to:
-      timbl@uvt.nl
+      lamasoftware (at ) science.ru.nl
 */
 
 #ifndef TICC_XML_TOOLS_H
@@ -118,6 +115,7 @@ namespace TiCC {
   }
 
   std::map<std::string,std::string> getNSvalues( const xmlNode * );
+  std::map<std::string,std::string> getDefinedNS( const xmlNode * );
 
   std::string serialize( const xmlNode& node );
 
@@ -153,6 +151,8 @@ namespace TiCC {
     xmlNode *MakeRoot( const std::string& );
     const std::string toString() const;
   private:
+    XmlDoc( const XmlDoc& ); // no copies please
+    XmlDoc& operator= ( const XmlDoc& ); // no copies please
     xmlDoc *the_doc;
   };
 
