@@ -1,19 +1,16 @@
 /*
-  $Id: XMLtools.cxx 17075 2014-03-31 10:54:22Z sloot $
-  $URL: https://ilk.uvt.nl/svn/sources/libticcutils/trunk/src/XMLtools.cxx $
-
-  Copyright (c) 1998 - 2014
+  Copyright (c) 2006 - 2016
+  CLST  - Radboud University
   ILK   - Tilburg University
-  CLiPS - University of Antwerp
 
   This file is part of ticcutils
 
-  timbl is free software; you can redistribute it and/or modify
+  ticcutils is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
   (at your option) any later version.
 
-  timbl is distributed in the hope that it will be useful,
+  ticcutils is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
@@ -22,9 +19,9 @@
   along with this program; if not, see <http://www.gnu.org/licenses/>.
 
   For questions and suggestions, see:
-      http://ilk.uvt.nl/software.html
+      https://github.com/LanguageMachines/ticcutils/issues
   or send mail to:
-      timbl@uvt.nl
+      lamasoftware (at ) science.ru.nl
 */
 
 #include <iostream>
@@ -100,6 +97,22 @@ namespace TiCC {
     return result;
   }
 
+  map<string,string> getDefinedNS( const xmlNode *node ){
+    map<string,string> result;
+    xmlNs *p = node->nsDef;
+    while ( p ){
+      string pre;
+      string val;
+  if ( p->prefix ){
+	pre = (char *)p->prefix;
+      }
+      val = (char *)p->href;
+      result[pre] = val;
+      p = p->next;
+    }
+    return result;
+  }
+
   //#define DEBUG_XPATH
 
   list<xmlNode*> FindLocal( xmlXPathContext* ctxt,
@@ -132,26 +145,22 @@ namespace TiCC {
 #ifdef DEBUG_XPATH
     {
       cerr << m.size() << " namespaces for node " << Name( ctxt->node ) << endl;
-      map<string,string>::const_iterator it = m.begin();
-      while ( it != m.end() ){
-	cerr << it->first << ":" << it->second << endl;
-	++it;
+      for ( auto const& it : m ){
+	cerr << it.first << ":" << it.second << endl;
       }
     }
 #endif
-    map<string,string>::const_iterator it = m.begin();
-    while ( it != m.end() ){
-      if ( it->first.empty() ){
+    for ( auto const& it : m ){
+      if ( it.first.empty() ){
 	xmlXPathRegisterNs( ctxt,
 			    (xmlChar*)defaultP.c_str(),
-			    (xmlChar*)it->second.c_str() );
+			    (xmlChar*)it.second.c_str() );
       }
       else {
 	xmlXPathRegisterNs( ctxt,
-			    (xmlChar*)it->first.c_str(),
-			    (xmlChar*)it->second.c_str() );
+			    (xmlChar*)it.first.c_str(),
+			    (xmlChar*)it.second.c_str() );
       }
-      ++it;
     }
   }
 
@@ -170,25 +179,20 @@ namespace TiCC {
 
   list<xmlNode*> FindNodes( xmlNode* node,
 			    const string& xPath ){
-    string xpath = replaceStarNS( xPath );
+  string xpath = replaceStarNS( xPath );
 #ifdef DEBUG_XPATH
-    cerr << "replaced " << xPath << " by " << xpath << endl;
+  cerr << "replaced " << xPath << " by " << xpath << endl;
 #endif
     xmlXPathContext* ctxt = xmlXPathNewContext( node->doc );
     ctxt->node = node;
     register_namespaces( ctxt );
     list<xmlNode*> nodes = FindLocal( ctxt, xpath );
-    list<xmlNode*>::const_iterator it = nodes.begin();
 #ifdef DEBUG_XPATH
-    if ( it ==  nodes.end() ){
+    if ( nodes.empty() ){
       cerr << "no " << xPath << " nodes found in " << Name(node) << endl;
     }
     else {
-      cerr << "Found " << xPath << " nodes found in " << Name(node) << endl;
-      while ( it != nodes.end() ){
-	cerr << "node " << Name(*it) << endl;
-	++it;
-      }
+      cerr << "Found " << nodes.size() << " nodes in " << Name(node) << endl;
     }
 #endif
     if (ctxt->namespaces != NULL)
