@@ -390,9 +390,6 @@ void test_bz2compression( const string& path ){
   assertEqual( buffer.substr(0,4), "This" );
   string cmd = "diff " + path + "small.txt bzout.txt";
   assertEqual( system( cmd.c_str() ), 0 );
-  assertTrue( gzDecompress( path + "nasty.bz2", "nasty.txt" ) );
-  cmd = "diff " + path + "nasty.bz2 nasty.txt";
-  assertEqual( system(cmd.c_str()), 0 );
 }
 
 void test_gzcompression( const string& path ){
@@ -505,7 +502,7 @@ void test_configuration( const string& path ){
 }
 
 void test_logstream( const string& path ){
-  ofstream uit( path + "testls.1" );
+  ofstream uit( "/tmp/testls.1" );
   LogStream ls( uit );
   ls.setstamp( NoStamp );
   *Log( ls ) << "test 1 level=" << ls.getlevel() << " threshold=" << ls.getthreshold() << endl;
@@ -532,7 +529,7 @@ void test_logstream( const string& path ){
   *Dbg( ls ) << "debug 5" << endl;
   *xDbg( ls ) << "x_debug 5" << endl;
   *xxDbg( ls ) << "xx_debug 5" << endl;
-  string cmd = "diff " + path + "testls.1 " + path + "testls.1.ok";
+  string cmd = "diff /tmp/testls.1 " + path + "testls.1.ok";
   assertEqual( system( cmd.c_str() ), 0 );
 }
 
@@ -571,9 +568,15 @@ int main( const int argc, const char* argv[] ){
   string testdir;
   bool dummy;
   opts1.is_present( 'd', testdir, dummy );
+#ifdef HAVE_BZLIB_H
   test_bz2compression( testdir );
+#endif
+#ifdef HAVE_LIBZ
   test_gzcompression( testdir );
+#endif
+#ifdef HAVE_LIBTAR_H
   test_tar( testdir );
+#endif
   test_fileutils( testdir );
   test_configuration( testdir );
   test_logstream( testdir );
