@@ -33,7 +33,9 @@
 #include "bzlib.h"
 #include "ticcutils/bz2stream.h"
 #endif
+#ifdef HAVE_LIBZ
 #include "ticcutils/gzstream.h"
+#endif
 
 using namespace std;
 
@@ -44,24 +46,30 @@ namespace TiCC {
   throw runtime_error( "unable to execute '" + f +"', BZ2 support not enabled." );
 }
 
-  bool bz2Compress( const string& inName, const string& outName ){
-  bz2fail( "bz2Compress()" );
-}
-  bool bz2Decompress( const string& inName, const string& outName ){
+  bool bz2Compress( const string&, const string& ){
+    bz2fail( "bz2Compress()" );
+    return false;
+  }
+  bool bz2Decompress( const string&, const string& ){
     bz2fail( "bz2Decompress()" );
-}
-  string bz2ReadStream( istream& is ){
+    return false;
+  }
+  string bz2ReadStream( istream& ){
     bz2fail( "bz2ReadStream()" );
-}
-  string bz2ReadFile( const string& inName ){
+    return "false";
+  }
+  string bz2ReadFile( const string& ){
     bz2fail( "bz2CReadFile()" );
-}
-  bool bz2WriteStream( ostream& outfile, const string& buffer ){
+    return "false";
+  }
+  bool bz2WriteStream( ostream&, const string& ){
     bz2fail( "bz2WriteStream()" );
-}
-  bool bz2WriteFile( const string& outName, const string& buffer ){
+    return false;
+  }
+  bool bz2WriteFile( const string&, const string& ){
     bz2fail( "bz2WriteFile()" );
-}
+    return false;
+  }
 #else
   bool bz2Compress( const string& inName, const string& outName ){
     std::ifstream infile( inName, std::ios::binary);
@@ -153,6 +161,33 @@ namespace TiCC {
   }
 #endif
 
+#ifndef HAVE_LIBZ
+  bool gzfail( const string&f ){
+    throw runtime_error( "unable to execute '" + f +"', GZ support not enabled." );
+    return false;
+  }
+  bool gzCompress( const string&, const string& ){
+    return gzfail( "gzCompress()" );
+  }
+  bool gzDecompress( const string&, const string& ){
+    return gzfail( "gzDecompress()" );
+  }
+  string gzReadStream( istream& ){
+    gzfail( "gzReadStream()" );
+    return "";
+  }
+  string gzReadFile( const string& ){
+    gzfail( "gzReadFile()" );
+    return "";
+  }
+  bool gzWriteStream( ostream&, const string& ){
+    return gzfail( "gbzWriteStream()" );
+  }
+  bool gzWriteFile( const string&, const string& ){
+    return gzfail( "gzWriteFile()" );
+  }
+
+#else
   string gzReadStream( istream& is ){
     string result;
     char c;
@@ -241,6 +276,6 @@ namespace TiCC {
       outfile << c;
     return true;
   }
-
+#endif
 
 }
